DoubleYAxis
===========

.. currentmodule:: stonerplots

.. autoclass:: DoubleYAxis
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DoubleYAxis.locations

   .. rubric:: Attributes Documentation

   .. autoattribute:: locations
